@@ -7,7 +7,7 @@ import tensorflow as tf
 from model_data_util.create_tt_data.model_data_convert import convertRawDataToModel
 
 from TTBenchmark.check_environment import check_env_info
-from constant import GDRIVE_PATH
+from TTBenchmark.constant import GDRIVE_PATH
 
 
 class BenchmarkData(NamedTuple):
